"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const conf_1 = require("./conf");
const message_1 = require("./message");
const { resolve } = path;
const { RdModes } = conf_1.default;
exports.validateRda = (useStrict = false) => {
    return useStrict;
};
exports.validateRdc = (useStrict = false) => {
    const { cwd, rdcConfPath, frameworks, } = conf_1.default;
    if (!fs.existsSync(rdcConfPath)) {
        throw Error(message_1.MRDC.UNRECOGNIZED);
    }
    const appDir = resolve(cwd, 'app');
    const templateDir = resolve(cwd, 'template');
    if (!fs.existsSync(appDir)) {
        throw Error(message_1.MRDC.WRONG_DIR_STRUCTURE_APP);
    }
    if (!fs.existsSync(templateDir)) {
        throw Error(message_1.MRDC.WRONG_DIR_STRUCTURE_TPL);
    }
    const rdcConf = require(rdcConfPath);
    if (!rdcConf.framework ||
        !Object.keys(frameworks).includes(rdcConf.framework)) {
        throw Error(message_1.MCOMMON.WRONG_FRAMEWORK_CONFIG);
    }
    const { mappings, docs, mode = RdModes.Integrate } = rdcConf;
    if (mode === conf_1.default.RdModes.Integrate &&
        (!mappings || !mappings.length)) {
        throw Error(message_1.MCOMMON.WRONG_MAPPING_CONFIG_MAPPING);
    }
    if (useStrict && (!docs || !docs.url)) {
        throw Error(message_1.MCOMMON.WRONG_DOCS_CONFIG);
    }
    if (!rdcConf.npm || !rdcConf.npm.name || !rdcConf.npm.version) {
        throw Error(message_1.MCOMMON.WRONG_NPM_CONFIG);
    }
    return rdcConf;
};
